California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 40 - CALIFORNIA CLEAN WATER, CLEAN AIR, SAFE NEIGHBORHOOD PARKS, AND COASTAL PROTECTION ACT OF 2002. AB. 1602 (2001) View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
970866 | NATURE CONSERVANCY ACTION FUND OF CALIFORNIA, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991829 | YES ON 40. PROTECT CALIFORNIA'S LAND, AIR AND WATER. SUPPORTED BY CONSERVATION GROUPS AND OWNERS OF OPEN SPACE. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1242194 | ANZA-BORREGO FOUNDATION COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1241819 | CALIFORNIA HERITAGE COALITION - A COMMITTEE FOR PROPOSITION 40 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1243044 | CALIFORNIA ASSOCIATION OF LOCAL CONSERVATION CORPS | SUPPORT